﻿using Microsoft.Win32;
using Syncfusion.UI.Xaml.Grid;
using Syncfusion.UI.Xaml.Grid.Converter;
using Syncfusion.XlsIO;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace ExportIcontoExcel
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void OnExcelExportDataGrid(object sender, RoutedEventArgs e)
        {
            var options = new ExcelExportingOptions();

            //GridCellExcelExportingEvent is assinged to CellsExportingEventHandler delegate
            options.CellsExportingEventHandler = GridCellExcelExportingEvent;
            var excelEngine = this.grid.ExportToExcel(this.grid.View, options);

            SaveFileDialog sfd = new SaveFileDialog
            {
                Filter = "Excel Files(*.xlsx)|*.xlsx"
            };

            if (sfd.ShowDialog() == true)
            {
                using (Stream stream = sfd.OpenFile())
                {
                    excelEngine.Excel.Workbooks[0].SaveAs(stream);
                }
                if (MessageBox.Show("Do you want to view the Excel file?", "Excel file has been created",
                    MessageBoxButton.YesNo, MessageBoxImage.Information) == MessageBoxResult.Yes)
                {
                    System.Diagnostics.Process.Start(sfd.FileName);
                }
            }
        }

        private void GridCellExcelExportingEvent(object sender, GridCellExcelExportingEventArgs e)
        {
            //Check whehter the CellType is RecordCell and the column name is IsCheck which is GridTemplateColumn contains the image.
            if (e.CellType == ExportCellType.RecordCell && e.ColumnName == "IsCheck")
            {
                //Access the fail image as default value
                System.Drawing.Image image = System.Drawing.Image.FromFile(@"..\..\Images\fail.png");
                //Images are exported based on the CellValue 
                if (e.CellValue.Equals("Pass"))
                {
                    //Access the image from the specified path 
                    image = System.Drawing.Image.FromFile(@"..\..\Images\pass.png");   
                }
                //Add Picture to the specific range of cell in Worksheet
                var pic = e.Range.Worksheet.Pictures.AddPicture(e.Range.Row, e.Range.Column, image);
                //Adjust Position of the picture based on the expected appearance in the exported cell
                pic.Left += 20;
                pic.Top += 5;
                //Adjust image size to the cell width and height when it's exceded
                if (image.Width > e.Range.ColumnWidth)
                    pic.Width = (int)e.Range.ColumnWidth;
                if (image.Height > e.Range.RowHeight)
                    pic.Height = (int)e.Range.RowHeight;
                e.Range.Cells[0].Value = null;
                e.Handled = true;
            }
        }
    }
}
